Crate diffsol_la

Crate diffsol_la 

diffsol-la

Linear algebra traits and backends for diffsol.

This crate provides the vector, matrix, and linear-solver abstractions used by diffsol, together with concrete implementations backed by nalgebra, faer, suitesparse (KLU), and CUDA.

Re-exports

pub use error::LaError;
pub use context::faer::FaerContext;
pub use context::nalgebra::NalgebraContext;
pub use context::Context;
pub use linear_op::LinearOp;
pub use linear_solver::LinearSolver;
pub use linear_solver::faer::sparse_lu::FaerSparseLU;
pub use linear_solver::FaerLU;
pub use linear_solver::NalgebraLU;
pub use matrix::default_solver::DefaultSolver;
pub use matrix::dense_faer_serial::FaerMat;
pub use matrix::dense_nalgebra_serial::NalgebraMat;
pub use matrix::sparse_faer::FaerSparseMat;
pub use matrix::DenseMatrix;
pub use matrix::Matrix;
pub use matrix::MatrixCommon;
pub use matrix::sparsity::Dense;
pub use matrix::sparsity::DenseRef;
pub use matrix::sparsity::MatrixSparsity;
pub use matrix::sparsity::MatrixSparsityRef;
pub use matrix::MatrixHost;
pub use matrix::MatrixRef;
pub use matrix::MatrixView;
pub use matrix::MatrixViewMut;
pub use scalar::scale;
pub use scalar::FaerScalar;
pub use scalar::IndexType;
pub use scalar::NalgebraScalar;
pub use scalar::Scalar;
pub use scalar::Scale;
pub use vector::DefaultDenseMatrix;
pub use vector::faer_serial::FaerVec;
pub use vector::faer_serial::FaerVecIndex;
pub use vector::faer_serial::FaerVecMut;
pub use vector::faer_serial::FaerVecRef;
pub use vector::nalgebra_serial::NalgebraVec;
pub use vector::nalgebra_serial::NalgebraVecMut;
pub use vector::nalgebra_serial::NalgebraVecRef;
pub use vector::Vector;
pub use vector::VectorCommon;
pub use vector::VectorHost;
pub use vector::VectorIndex;
pub use vector::VectorRef;
pub use vector::VectorView;
pub use vector::VectorViewMut;

Modules

context
Context objects for managing device resources for vectors and matrices (e.g. device streams, threading pools, etc.).
error
Error types and handling.
linear_op
The LinearOp trait describing a linear operator A for use with LinearSolver.
linear_solver
Linear solver implementations and traits.
matrix
Matrix types and operations.
scalar
Scalar types and traits.
vector
Vector types and traits.

Macros

la_other_error
linear_solver_error
matrix_error