Module error

Module error 

Error types and handling.

This module defines the LaError enum and specialized error variants for the linear algebra layer, including matrix, linear-solver, and (optional) CUDA errors.

Enums

LaError
Error type for the diffsol linear algebra crate (diffsol-la).
LinearSolverError
Possible errors that can occur when solving a linear problem
MatrixError
Possible errors for matrix operations