pub enum LaError {
LinearSolverError(LinearSolverError),
MatrixError(MatrixError),
Other(String),
}Expand description
Error type for the diffsol linear algebra crate (diffsol-la).
This wraps the errors that can occur in the linear algebra layer: matrix
operations, linear solvers, and (optionally) CUDA. It is re-exported by the
diffsol crate and can be converted into diffsol’s top-level error type.
Variants