The LinearOp trait describing a linear operator A for use with LinearSolver.
Traits
- Linear
Op - A linear operator
Afor use with the crate::LinearSolver trait.
The LinearOp trait describing a linear operator A for use with LinearSolver.
A for use with the crate::LinearSolver trait.