Module linear_solver

Module linear_solver 

Linear solver implementations and traits.

This module defines the LinearSolver trait for solving linear systems and provides implementations:

  • Direct solvers: NalgebraLU, FaerLU, FaerSparseLU
  • Optional sparse solvers: KLU (requires suitesparse feature)
  • GPU solvers: CudaLU (requires cuda feature)

The linear solver is a critical component used internally by nonlinear solvers to solve Newton systems.

Re-exports

pub use faer::lu::LU as FaerLU;
pub use nalgebra::lu::LU as NalgebraLU;

Modules

faer
nalgebra

Traits

LinearSolver
A solver for the linear problem Ax = b, where A is a LinearOp.