Module matrix

Module matrix 

Matrix types and operations.

This module defines the Matrix trait and related traits for matrix operations:

Implementations are provided for:

Modules

default_solver
dense_faer_serial
dense_nalgebra_serial
extract_block
sparse_faer
sparsity

Traits

DenseMatrix
A dense column-major matrix with efficient column access operations.
Matrix
A base matrix trait supporting both sparse and dense matrices.
MatrixCommon
Common interface for matrix types, providing access to scalar type, context, and dimensions.
MatrixHost
A host matrix is a matrix type whose vector type is hosted on the CPU.
MatrixMutOpsByValue
In-place operations on matrices (addition and subtraction).
MatrixOpsByValue
Operations on matrices by value (addition and subtraction).
MatrixRef
A trait allowing for references to implement matrix operations
MatrixView
A borrowed immutable view of a dense matrix, supporting read-only arithmetic operations.
MatrixViewMut
A mutable view of a dense matrix, supporting in-place operations and modifications.