DefaultDenseMatrix

Trait DefaultDenseMatrix 

pub trait DefaultDenseMatrix: Vector {
    type M: DenseMatrix<V = Self, T = Self::T, C = Self::C>;
}
Marker trait for vectors that have a default associated dense matrix type.

This trait associates a vector type with its corresponding dense matrix representation, enabling vectors to be easily combined with matrix types for linear algebra operations.

Required Associated Types

type M: DenseMatrix<V = Self, T = Self::T, C = Self::C>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors