Linear solver implementations and traits.
This module defines the LinearSolver trait for solving linear systems and provides implementations:
- Direct solvers: NalgebraLU, FaerLU, FaerSparseLU
- Optional sparse solvers:
KLU(requiressuitesparsefeature) - GPU solvers:
CudaLU(requirescudafeature)
The linear solver is a critical component used internally by nonlinear solvers to solve Newton systems.
Re-exports
Modules
Traits
- Linear
Solver - A solver for the linear problem
Ax = b, whereAis a LinearOp.