Matrix types and operations.
This module defines the Matrix trait and related traits for matrix operations:
- DenseMatrix for dense column-major matrices
- MatrixView and MatrixViewMut for borrowed views
- Sparsity detection and handling
Implementations are provided for:
- Dense matrices: NalgebraMat, FaerMat
- Sparse matrices: FaerSparseMat
- GPU matrices:
CudaMat(requirescudafeature)
Modules
Traits
- Dense
Matrix - A dense column-major matrix with efficient column access operations.
- Matrix
- A base matrix trait supporting both sparse and dense matrices.
- Matrix
Common - Common interface for matrix types, providing access to scalar type, context, and dimensions.
- Matrix
Host - A host matrix is a matrix type whose vector type is hosted on the CPU.
- Matrix
MutOps ByValue - In-place operations on matrices (addition and subtraction).
- Matrix
OpsBy Value - Operations on matrices by value (addition and subtraction).
- Matrix
Ref - A trait allowing for references to implement matrix operations
- Matrix
View - A borrowed immutable view of a dense matrix, supporting read-only arithmetic operations.
- Matrix
View Mut - A mutable view of a dense matrix, supporting in-place operations and modifications.