pub trait VectorViewMut<'a>:
VectorMutOpsByValue<Self::View>
+ VectorMutOpsByValue<Self::Owned>
+ for<'b> VectorMutOpsByValue<&'b Self::View>
+ for<'b> VectorMutOpsByValue<&'b Self::Owned>
+ MulAssign<Scale<Self::T>> {
type Owned;
type View;
type Index: VectorIndex;
// Required methods
fn copy_from(&mut self, other: &Self::Owned);
fn copy_from_view(&mut self, other: &Self::View);
fn axpy(&mut self, alpha: Self::T, x: &Self::Owned, beta: Self::T);
fn set_index(&mut self, index: IndexType, value: Self::T);
}Expand description
A mutable view into a vector, supporting in-place operations and modifications.
This trait represents a temporary mutable reference to a vector’s data, allowing in-place
arithmetic operations (+=, -=, *=) and other modifications. Mutable views can be created
via the as_view_mut() method on a Vector.
Required Associated Types
Required Methods
Sourcefn copy_from_view(&mut self, other: &Self::View)
fn copy_from_view(&mut self, other: &Self::View)
Copy values from another vector view into this view.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".